==> scrm-center-api-0.0.5-87-20210731.122446-1-sources.jar: cn/com/duiba/scrm/center/api/remoteservice/chatgroup/RemoteChatGroupService.java <==
package cn.com.duiba.scrm.center.api.remoteservice.chatgroup;

import cn.com.duiba.boot.netflix.feign.AdvancedFeignClient;
import cn.com.duiba.scrm.center.api.dto.chatgroup.ChatGroupDetailDto;
import cn.com.duiba.scrm.center.api.dto.chatgroup.ChatGroupDto;
import cn.com.duiba.scrm.center.api.dto.chatgroup.ChatGroupStatisticDto;
import cn.com.duiba.scrm.center.api.param.chatgroup.ChatGroupDetailParam;
import cn.com.duiba.scrm.center.api.param.chatgroup.ChatGroupQueryParam;
import cn.com.duiba.scrm.center.api.param.chatgroup.ChatGroupStatisticParam;
import cn.com.duiba.scrm.common.result.ScrmPageResult;
import cn.com.duiba.scrm.common.result.ScrmResult;

import java.util.List;

/**
 * 企业微信群 RemoteService
 *
 * @author xiaotian
 * 2021-7-24 13:52:14
 */
@AdvancedFeignClient
public interface RemoteChatGroupService {
    /**
     * 新增记录
     */
    Boolean save(ChatGroupDto dto);

    /**
     * 根据id删除
     */
    Boolean deleteById(Long id);

    /**
     * 根据id更新
     */
    Boolean updateById(ChatGroupDto dto);

    /**
     * 根据id获取
     */
    ChatGroupDto getById(Long id);


    /**
     * 查询客户群
     */
    ScrmResult<ScrmPageResult<ChatGroupDto>> queryPage(ChatGroupQueryParam param);


    ScrmResult<ChatGroupDetailDto> detail(ChatGroupDetailParam param);

    /**
     * 批量统计多个群的指定日期的统计
     */
    ScrmResult<List<ChatGroupStatisticDto>> statistic(ChatGroupStatisticParam param);

    /*
     * 根据企业Id和chatId列表，获取群列表
     * @param scCorpId
     * @param chatIds
     * @return
     */
    List<ChatGroupDto>  getByCorpIdAndChatIdList(Long scCorpId, List<String> chatIds);


    /*
     * 根据企业Id，获取群列表
     * @param scCorpId
     * @param chatIds
     * @return
     */
    List<ChatGroupDto>  getByCorpId(Long scCorpId);

}

==> scrm-center-api-0.0.6-20210811.131653-27-sources.jar: cn/com/duiba/scrm/center/api/remoteservice/chatgroup/RemoteChatGroupService.java <==
package cn.com.duiba.scrm.center.api.remoteservice.chatgroup;

import cn.com.duiba.boot.netflix.feign.AdvancedFeignClient;
import cn.com.duiba.scrm.center.api.dto.chatgroup.ChatGroupDetailDto;
import cn.com.duiba.scrm.center.api.dto.chatgroup.ChatGroupDto;
import cn.com.duiba.scrm.center.api.dto.chatgroup.ChatGroupStatisticDto;
import cn.com.duiba.scrm.center.api.param.chatgroup.ChatGroupDetailParam;
import cn.com.duiba.scrm.center.api.param.chatgroup.ChatGroupQueryParam;
import cn.com.duiba.scrm.center.api.param.chatgroup.ChatGroupStatisticParam;
import cn.com.duiba.scrm.common.result.ScrmPageResult;
import cn.com.duiba.scrm.common.result.ScrmResult;

import java.util.List;

/**
 * 企业微信群 RemoteService
 *
 * @author xiaotian
 * 2021-7-24 13:52:14
 */
@AdvancedFeignClient
public interface RemoteChatGroupService {
    /**
     * 新增记录
     */
    Boolean save(ChatGroupDto dto);

    /**
     * 根据id删除
     */
    Boolean deleteById(Long id);

    /**
     * 根据id更新
     */
    Boolean updateById(ChatGroupDto dto);

    /**
     * 根据id获取
     */
    ChatGroupDto getById(Long id);


    /**
     * 查询客户群
     */
    ScrmResult<ScrmPageResult<ChatGroupDto>> queryPage(ChatGroupQueryParam param);


    ScrmResult<ChatGroupDetailDto> detail(ChatGroupDetailParam param);

    /**
     * 批量统计多个群的指定日期的统计
     */
    ScrmResult<List<ChatGroupStatisticDto>> statistic(ChatGroupStatisticParam param);

    /*
     * 根据企业Id和chatId列表，获取群列表
     * @param scCorpId
     * @param chatIds
     * @return
     */
    List<ChatGroupDto>  getByCorpIdAndChatIdList(Long scCorpId, List<String> chatIds);


    /*
     * 根据企业Id，获取群列表
     * @param scCorpId
     * @param chatIds
     * @return
     */
    List<ChatGroupDto>  getByCorpId(Long scCorpId);


    /**
     * 统计客户群数量
     * @param chatGroupQueryParam
     * @return
     */
    Long countByParam(ChatGroupQueryParam chatGroupQueryParam);

    /**
     * 根据群主查询
     * @param scCorpId
     * @param scUserId
     * @return
     */
    List<ChatGroupDto> getByScUserId(Long scCorpId, Long scUserId);

    /**
     * 根据群主数组查询
     * @param scCorpId
     * @param scUserIds
     * @return
     */
    List<ChatGroupDto> getByScUserIds(Long scCorpId, List<Long> scUserIds);
}
